Applications
============

.. autoclass:: steampak.libsteam.resources.apps.Applications
    :inherited-members:


Current Application
-------------------

.. autoclass:: steampak.libsteam.resources.apps.CurrentApplication
    :inherited-members:


Application
-----------

.. autoclass:: steampak.SteamApplication

.. autoclass:: steampak.libsteam.resources.apps.Application
    :inherited-members:


DLC
---

.. autoclass:: steampak.SteamDlc

.. autoclass:: steampak.libsteam.resources.apps.Dlc
    :inherited-members:

